pub enum FilenamePolicy {
Original,
Custom(PathBuf),
}Expand description
How to name a file on disk.
Variants
Original
Use the canonical filename from the package entry (for debs) or the basename of the path inside the deb (for extracts).
Custom(PathBuf)
Use a caller-supplied filename.
Implementations
Sourceimpl FilenamePolicy
impl FilenamePolicy
Sourcepub fn original() -> FilenamePolicy
pub fn original() -> FilenamePolicy
Returns a policy for using the original filename.
Sourcepub fn custom(path: impl Into<PathBuf>) -> FilenamePolicy
pub fn custom(path: impl Into<PathBuf>) -> FilenamePolicy
Returns a policy for using a custom filename.