ProgressEvent

Enum ProgressEvent 

pub enum ProgressEvent<'a> {
    DownloadStarted {
        url: &'a Url,
        total_bytes: Option<u64>,
    },
    DownloadProgress {
        url: &'a Url,
        bytes: u64,
        total_bytes: Option<u64>,
    },
    DownloadComplete {
        url: &'a Url,
    },
    ExtractStarted {
        path: &'a Path,
        total_bytes: Option<u64>,
    },
    ExtractProgress {
        path: &'a Path,
        bytes: u64,
        total_bytes: Option<u64>,
    },
    ExtractComplete {
        path: &'a Path,
    },
}
Progress event emitted during download and extraction operations.

Variants



DownloadStarted

An HTTP download has started.

Fields

url: &'a Url

URL being downloaded.

total_bytes: Option<u64>

Total size in bytes, if known from the Content-Length header.



DownloadProgress

Bytes have been received.

Fields

url: &'a Url

URL being downloaded.

bytes: u64

Number of bytes received so far.

total_bytes: Option<u64>

Total size in bytes, if known from the Content-Length header.



DownloadComplete

An HTTP download has completed.

Fields

url: &'a Url

URL that was downloaded.



ExtractStarted

Extraction of a file from an archive has started.

Fields

path: &'a Path

Path of the file being extracted.

total_bytes: Option<u64>

Total uncompressed size in bytes, if known.



ExtractProgress

Bytes have been extracted from an archive.

Fields

path: &'a Path

Path of the file being extracted.

bytes: u64

Number of bytes extracted so far.

total_bytes: Option<u64>

Total uncompressed size in bytes, if known.



ExtractComplete

Extraction of a file from an archive has completed.

Fields

path: &'a Path

Path of the file that was extracted.