IsrCache

Struct IsrCache 

pub struct IsrCache { /* private fields */ }
A cache for OS kernel profiles.

Manages the download and extraction of necessary debug symbols.

Implementations

Source

impl IsrCache

pub fn new(output_directory: impl Into<PathBuf>) -> Result<Self, Error>

Creates a new IsrCache instance, initializing it with the provided directory. If the directory doesn’t exist, it attempts to create it.

pub fn with_progress( self, f: impl Fn(ProgressEvent<'_>) + Send + Sync + 'static, ) -> Self

Sets a progress callback for download and extraction operations.

pub fn with_offline(self, offline: bool) -> Self

Enables or disables offline mode.

In offline mode the cache only uses already-downloaded artifacts and never reaches out to the network.

pub fn with_ubuntu_downloader( self, ubuntu_downloader: UbuntuSymbolDownloader, ) -> Self

Overrides the default UbuntuSymbolDownloader.

pub fn ubuntu_downloader(&self) -> &UbuntuSymbolDownloader

Returns the UbuntuSymbolDownloader, lazily initializing it.

pub fn with_symbol_downloader(self, symbol_downloader: SymbolDownloader) -> Self

Overrides the default SymbolDownloader.

pub fn symbol_downloader(&self) -> &SymbolDownloader

Returns the SymbolDownloader, lazily initializing it.

pub fn entry_from_linux_banner( &self, linux_banner: &str, ) -> Result<Entry, Error>

Creates or retrieves a cached profile based on a Linux kernel banner.

Parses the banner to determine the kernel version and downloads the necessary debug symbols and system map if not present in the cache. Generates and stores the profile, returning its path.

pub fn download_from_ubuntu_version_signature( &self, version_signature: UbuntuVersionSignature, ) -> Result<UbuntuSymbolPaths, Error>

Downloads and extracts the kernel image, debug symbols, and System.map for the given Ubuntu version signature.

Returns an UbuntuSymbolPaths with the output directory and the per-artifact paths.

pub fn entry_from_codeview(&self, codeview: CodeView) -> Result<Entry, Error>

Creates or retrieves a cached profile from a CodeView debug information structure.

If a profile for the given CodeView information already exists in the cache, its path is returned. Otherwise, the necessary PDB file is downloaded, the profile is generated and stored in the cache, and its path is returned.

pub fn entry_from_pe(&self, path: impl AsRef<Path>) -> Result<Entry, Error>

Creates or retrieves a cached profile from a PE file.

Extracts the CodeView debug information from the PE file and delegates to entry_from_codeview.

pub fn download_from_codeview( &self, codeview: CodeView, ) -> Result<PathBuf, Error>

Downloads or retrieves a cached PDB from its CodeView record.

pub fn download_from_image_signature( &self, image_signature: ImageSignature, ) -> Result<PathBuf, Error>

Downloads or retrieves a cached PE binary from its ImageSignature.

PE binaries are cached at: <cache>/windows/<name>/<timestamp><size_of_image>/<name>

Returns the path to the cached binary.