Profile

Struct Profile 

pub struct Profile<'a> { /* private fields */ }
A typed view over an archived profile.

Implementations

Source

impl<'a> Profile<'a>

pub fn from_archived(archived: &'a ArchivedProfile) -> Profile<'a>

Constructs a typed view over an archived profile.

pub fn architecture(&self) -> Architecture

Returns the architecture of the profile.

pub fn enums(&self) -> impl ExactSizeIterator

Returns the enums.

pub fn structs(&self) -> impl ExactSizeIterator

Returns the structs.

pub fn symbols(&self) -> impl ExactSizeIterator

Returns the symbols.

pub fn type_size(&self, ty: Type<'a>) -> Option<u64>

Returns the size of a given type in bytes.

pub fn enum_size(&self, name: &str) -> Option<u64>

Returns the size of an enum type in bytes.

pub fn struct_size(&self, name: &str) -> Option<u64>

Returns the size of a struct type in bytes.

pub fn pointer_size(&self) -> u64

Returns the size of a pointer in bytes.

pub fn find_enum(&self, type_name: &str) -> Option<Enum<'a>>

Finds an enum by name.

pub fn find_struct(&self, type_name: &str) -> Option<Struct<'a>>

Finds a struct by name.

pub fn find_symbol(&self, symbol_name: &str) -> Option<u64>

Finds a symbol by name.

pub fn lookup_symbol(&self, rva: u64) -> Option<Symbol<'a>>

Returns the symbol whose RVA is closest to rva without exceeding it.

Useful for resolving an address to the containing function.