pub struct SymbolDownloader { /* private fields */ }Expand description
Downloads PDBs and PE binaries from one or more Microsoft symbol servers.
Implementations
Sourceimpl SymbolDownloader
impl SymbolDownloader
Sourcepub fn builder() -> SymbolDownloaderBuilder
pub fn builder() -> SymbolDownloaderBuilder
Create an instance of SymbolDownloader using the builder syntax
Sourceimpl SymbolDownloader
impl SymbolDownloader
Sourcepub fn lookup(&self, request: &SymbolRequest) -> Option<PathBuf>
pub fn lookup(&self, request: &SymbolRequest) -> Option<PathBuf>
Returns the cached path for request, or None if it is not on disk.