pub struct Profile<'a> { /* private fields */ }Expand description
A typed view over an archived profile.
Implementations
Sourceimpl<'a> Profile<'a>
impl<'a> Profile<'a>
Sourcepub fn from_archived(archived: &'a ArchivedProfile) -> Profile<'a>
pub fn from_archived(archived: &'a ArchivedProfile) -> Profile<'a>
Constructs a typed view over an archived profile.
Sourcepub fn architecture(&self) -> Architecture
pub fn architecture(&self) -> Architecture
Returns the architecture of the profile.
Sourcepub fn enums(&self) -> impl ExactSizeIterator
pub fn enums(&self) -> impl ExactSizeIterator
Returns the enums.
Sourcepub fn structs(&self) -> impl ExactSizeIterator
pub fn structs(&self) -> impl ExactSizeIterator
Returns the structs.
Sourcepub fn symbols(&self) -> impl ExactSizeIterator
pub fn symbols(&self) -> impl ExactSizeIterator
Returns the symbols.
Sourcepub fn type_size(&self, ty: Type<'a>) -> Option<u64>
pub fn type_size(&self, ty: Type<'a>) -> Option<u64>
Returns the size of a given type in bytes.
Sourcepub fn struct_size(&self, name: &str) -> Option<u64>
pub fn struct_size(&self, name: &str) -> Option<u64>
Returns the size of a struct type in bytes.
Sourcepub fn pointer_size(&self) -> u64
pub fn pointer_size(&self) -> u64
Returns the size of a pointer in bytes.
Sourcepub fn find_struct(&self, type_name: &str) -> Option<Struct<'a>>
pub fn find_struct(&self, type_name: &str) -> Option<Struct<'a>>
Finds a struct by name.
Sourcepub fn find_symbol(&self, symbol_name: &str) -> Option<u64>
pub fn find_symbol(&self, symbol_name: &str) -> Option<u64>
Finds a symbol by name.
Sourcepub fn lookup_symbol(&self, rva: u64) -> Option<Symbol<'a>>
pub fn lookup_symbol(&self, rva: u64) -> Option<Symbol<'a>>
Returns the symbol whose RVA is closest to rva without exceeding it.
Useful for resolving an address to the containing function.