pub struct UbuntuVersionSignature {
pub release: String,
pub revision: String,
pub kernel_flavour: String,
pub mainline_kernel_version: String,
}Expand description
Ubuntu kernel version signature, as embedded in the UTS version string.
Fields
release: StringUpstream kernel release, e.g. 6.8.0.
revision: StringUbuntu revision, e.g. 40.40~22.04.3.
kernel_flavour: StringKernel flavour, e.g. generic, lowlatency.
mainline_kernel_version: StringMainline kernel version the Ubuntu kernel is based on, e.g. 6.8.12.
Implementations
Sourceimpl UbuntuVersionSignature
impl UbuntuVersionSignature
Sourcepub fn revision_short(&self) -> &str
pub fn revision_short(&self) -> &str
Short revision, the portion before the first ..
Sourcepub fn kernel_release(&self) -> String
pub fn kernel_release(&self) -> String
{release}-{revision_short}-{kernel_flavour}, e.g. 6.8.0-40-generic.
Sourcepub fn kernel_version(&self) -> String
pub fn kernel_version(&self) -> String
{release}-{revision}, e.g. 6.8.0-40.40~22.04.3.
Sourcepub fn subdirectory(&self) -> PathBuf
pub fn subdirectory(&self) -> PathBuf
Subdirectory {kernel_version}-{kernel_flavour}.